<?php

namespace Drupal\group_forum\Plugin\GroupContentEnabler;

use Drupal\group\Plugin\GroupContentEnablerBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a content enabler for forum containers.
 *
 * @GroupContentEnabler(
 *   id = "group_forum",
 *   label = @Translation("Group forum"),
 *   description = @Translation("Adds forum containers to groups both publicly and privately."),
 *   entity_type_id = "taxonomy_term",
 *   entity_access = FALSE,
 *   pretty_path_key = "forum",
 *   enforced = TRUE,
 *   reference_label = @Translation("Forum container"),
 *   reference_description = @Translation("The title of the forum container to add to the group"),
 * )
 */
class GroupForum extends GroupContentEnablerBase {

  /**
   * {@inheritdoc}
   */
  protected function getTargetEntityPermissions(): array {
    $permissions = parent::getTargetEntityPermissions();
    $plugin_id = $this->getPluginId();

    // Add a 'view unpublished' permission by re-using most of the 'view' one.
    $original = $permissions["view $plugin_id entity"];
    $permissions["view unpublished $plugin_id entity"] = [
      'title' => str_replace('View ', 'View unpublished ', $original['title']),
    ] + $original;

    return $permissions;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $config = parent::defaultConfiguration();
    $config['entity_cardinality'] = 1;
    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    // Disable the entity cardinality field as the functionality of this module
    // relies on a cardinality of 1. We don't just hide it, though, to keep a UI
    // that's consistent with other content enabler plugins.
    $info = $this->t("This field has been disabled by the plugin to guarantee the functionality that's expected of it.");
    $form['entity_cardinality']['#disabled'] = TRUE;
    $form['entity_cardinality']['#description'] .= '<br /><em>' . $info . '</em>';

    return $form;
  }

}
